// The root folder for this documentation category is `pages/docs`
//
// - A string refers to the name of a file
// - A "category" value refers to the name of a directory
// - All directories must have an "index.mdx" file to serve as
//   the landing page for the category

export default [
  {
    category: 'install',
    content: [
      'quickstart',
      {
        category: 'production',
        content: [
          'requirements',
          {
            title: 'Reference Architecture',
            href:
              'https://learn.hashicorp.com/tutorials/nomad/production-reference-architecture-vm-with-consul',
          },
          {
            title: 'Deployment Guide',
            href:
              'https://learn.hashicorp.com/tutorials/nomad/production-deployment-guide-vm-with-consul',
          },
        ],
      },
      'windows-service',
    ],
  },
  { category: 'upgrade', content: ['upgrade-specific'] },
  {
    category: 'integrations',
    content: ['consul-integration', 'consul-connect', 'vault-integration'],
  },
  '-----------',
  {
    category: 'internals',
    content: [
      'architecture',
      {
        category: 'plugins',
        content: ['base', 'task-drivers', 'devices', 'csi'],
      },
      {
        category: 'scheduling',
        content: ['scheduling', 'preemption'],
      },
      'consensus',
      'filesystem',
      'gossip',
      'security',
    ],
  },
  {
    category: 'configuration',
    content: [
      'acl',
      'audit',
      'autopilot',
      'client',
      'consul',
      'plugin',
      'sentinel',
      'server',
      'server_join',
      'telemetry',
      'tls',
      'vault',
    ],
  },
  {
    category: 'commands',
    content: [
      {
        category: 'acl',
        content: [
          'bootstrap',
          'policy-apply',
          'policy-delete',
          'policy-info',
          'policy-list',
          'token-create',
          'token-delete',
          'token-info',
          'token-list',
          'token-self',
          'token-update',
        ],
      },
      'agent',
      'agent-info',
      {
        category: 'alloc',
        content: ['exec', 'fs', 'logs', 'restart', 'signal', 'status', 'stop'],
      },
      {
        category: 'deployment',
        content: [
          'fail',
          'list',
          'pause',
          'promote',
          'resume',
          'status',
          'unblock',
        ],
      },
      'eval-status',
      {
        category: 'job',
        content: [
          'deployments',
          'dispatch',
          'eval',
          'history',
          'init',
          'inspect',
          'plan',
          'periodic-force',
          'promote',
          'revert',
          'run',
          'scale',
          'scaling-events',
          'status',
          'stop',
          'validate',
        ],
      },
      {
        category: 'license',
        content: ['get', 'put'],
      },
      'monitor',
      {
        category: 'namespace',
        content: ['apply', 'delete', 'inspect', 'list', 'status'],
      },
      {
        category: 'node',
        content: ['config', 'drain', 'eligibility', 'status'],
      },
      {
        category: 'operator',
        content: [
          'autopilot-get-config',
          'autopilot-set-config',
          'debug',
          'keygen',
          'keyring',
          'metrics',
          'raft-list-peers',
          'raft-remove-peer',
          'snapshot-agent',
          'snapshot-inspect',
          'snapshot-restore',
          'snapshot-save',
        ],
      },
      { category: 'plugin', content: ['status'] },
      {
        category: 'quota',
        content: ['apply', 'delete', 'init', 'inspect', 'list', 'status'],
      },
      {
        category: 'recommendation',
        content: ['apply', 'dismiss', 'info', 'list'],
      },
      { category: 'scaling', content: ['policy-info', 'policy-list'] },
      { category: 'sentinel', content: ['apply', 'delete', 'list', 'read'] },
      { category: 'server', content: ['force-leave', 'join', 'members'] },
      'status',
      { category: 'system', content: ['gc', 'reconcile-summaries'] },
      'ui',
      'version',
      {
        category: 'volume',
        content: ['deregister', 'detach', 'status', 'register'],
      },
    ],
  },
  '----------',
  {
    category: 'job-specification',
    content: [
      {
        category: 'hcl2',
        content: [
          'expressions',
          {
            category: 'functions',
            content: [
              {
                category: 'collection',
                name: 'Collection Functions',
                content: [
                  'chunklist',
                  'coalesce',
                  'coalescelist',
                  'compact',
                  'concat',
                  'contains',
                  'distinct',
                  'element',
                  'flatten',
                  'index-fn',
                  'keys',
                  'length',
                  'lookup',
                  'merge',
                  'range',
                  'reverse',
                  'setintersection',
                  'setproduct',
                  'setunion',
                  'slice',
                  'sort',
                  'values',
                  'zipmap',
                ],
              },
              {
                category: 'conversion',
                name: 'Type Conversion Functions',
                content: ['can', 'convert', 'try'],
              },
              {
                category: 'crypto',
                name: 'Hash and Crypto Functions',
                content: [
                  'bcrypt',
                  'md5',
                  'rsadecrypt',
                  'sha1',
                  'sha256',
                  'sha512',
                ],
              },
              {
                category: 'datetime',
                name: 'Date and Time Functions',
                content: ['formatdate', 'timeadd'],
              },
              {
                category: 'encoding',
                name: 'Encoding Functions',
                content: [
                  'base64decode',
                  'base64encode',
                  'csvdecode',
                  'jsondecode',
                  'jsonencode',
                  'urlencode',
                  'yamldecode',
                  'yamlencode',
                ],
              },
              {
                category: 'file',
                name: 'Filesystem Functions',
                content: [
                  'abspath',
                  'basename',
                  'dirname',
                  'file',
                  'fileexists',
                  'fileset',
                  'pathexpand',
                ],
              },
              {
                category: 'ipnet',
                name: 'IP Network Functions',
                content: [
                  'cidrhost',
                  'cidrnetmask',
                  'cidrsubnet',
                  'cidrsubnets',
                ],
              },
              {
                category: 'numeric',
                name: 'Numeric Functions',
                content: [
                  'abs',
                  'ceil',
                  'floor',
                  'log',
                  'max',
                  'min',
                  'parseint',
                  'pow',
                  'signum',
                ],
              },
              {
                category: 'string',
                name: 'String Functions',
                content: [
                  'chomp',
                  'format',
                  'formatlist',
                  'indent',
                  'join',
                  'lower',
                  'regex_replace',
                  'replace',
                  'split',
                  'strrev',
                  'substr',
                  'title',
                  'trim',
                  'trimprefix',
                  'trimspace',
                  'trimsuffix',
                  'upper',
                ],
              },
              {
                category: 'uuid',
                name: 'UUID Functions',
                content: ['uuidv4', 'uuidv5'],
              },
            ],
          },
          'locals',
          'syntax',
          'variables',
        ],
      },
      'artifact',
      'affinity',
      'check_restart',
      'connect',
      'constraint',
      'csi_plugin',
      'device',
      'dispatch_payload',
      'env',
      'ephemeral_disk',
      'expose',
      'gateway',
      'group',
      'job',
      'lifecycle',
      'logs',
      'meta',
      'migrate',
      'multiregion',
      'network',
      'parameterized',
      'periodic',
      'proxy',
      'reschedule',
      'resources',
      'restart',
      'scaling',
      'service',
      'sidecar_service',
      'sidecar_task',
      'spread',
      'task',
      'template',
      'update',
      'upstreams',
      'vault',
      'volume',
      'volume_mount',
    ],
  },
  {
    category: 'drivers',
    content: [
      'docker',
      'exec',
      'java',
      'podman',
      'qemu',
      'raw_exec',
      {
        category: 'external',
        content: [
          'containerd',
          'firecracker-task-driver',
          'jail-task-driver',
          'lxc',
          'pot',
          'rkt',
          'singularity',
          'nspawn',
          'iis',
        ],
      },
    ],
  },
  {
    category: 'devices',
    content: [
      'nvidia',
      {
        category: 'external',
        content: [
          'usb'
        ]
      }
    ],
  },
  'schedulers',
  { category: 'runtime', content: ['environment', 'interpolation'] },
  {
    category: 'autoscaling',
    content: [
      'agent',
      'api',
      'cli',
      'policy',
      'telemetry',
      {
        category: 'plugins',
        content: ['apm', 'strategy', 'target'],
      },
      {
        category: 'internals',
        content: ['checks'],
      },
    ],
  },
  {
    category: 'operations',
    content: [
      'nomad-agent',
      'telemetry',
      'metrics',
      {
        title: 'Cluster Management',
        href: 'https://learn.hashicorp.com/collections/nomad/manage-clusters',
      },
      {
        title: 'Transport Security',
        href:
          'https://learn.hashicorp.com/collections/nomad/transport-security',
      },
      {
        title: 'Access Control',
        href: 'https://learn.hashicorp.com/collections/nomad/access-control',
      },
    ],
  },
  '------------',
  {
    category: 'nomad-vs-kubernetes',
    content: ['alternative', 'supplement'],
  },
  'ecosystem',
  'who-uses-nomad',
  'enterprise',
  'faq',
]
